<?php
/**
 * @copyright    Copyright (C) 2009-2018 ACYBA SAS - All rights reserved..
 * @license        GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die('Restricted access');

class plgAcymailingmijoshop extends JPlugin{
	function __construct(&$subject, $config){
		parent::__construct($subject, $config);
		$this->name = 'mijoshop';
		if(!isset($this->params)){
			$plugin = JPluginHelper::getPlugin('acymailing', $this->name);
			$this->params = new acyParameter($plugin->params);
		}

		//check if the component is installed
		if(!file_exists(JPATH_SITE.DS.'components'.DS.'com_mijoshop')){
			$this->component_installed = false;
		}else{
			$this->component_installed = true;
		}

		$this->lang_id = acymailing_loadResult('SELECT lang_id FROM #__languages WHERE lang_code = '.acymailing_escapeDB(JFactory::getConfig()->get('language')));
		$this->lang_id = intval($this->lang_id);
	}

	function acymailing_getPluginType(){
		if(!$this->component_installed){
			return;
		}
		$onePlugin = new stdClass();
		$onePlugin->name = 'MijoShop';
		$onePlugin->function = 'acymailing_'.$this->name.'_show';
		$onePlugin->help = 'plugin-'.$this->name;
		return $onePlugin;
	}

	function acymailing_mijoshop_show(){
		$config = acymailing_config();

		//We will need the latest developped functions
		if(version_compare($config->get('version'), '5.7.0', '<')){
			acymailing_display('Please download and install the latest AcyMailing version otherwise this plugin will NOT work', 'error');
			return;
		}

		
		acymailing_loadLanguageFile('com_mijoshop', JPATH_SITE);

		$pageInfo = new stdClass();
		$pageInfo->filter = new stdClass();
		$pageInfo->filter->order = new stdClass();
		$pageInfo->limit = new stdClass();
		$pageInfo->elements = new stdClass();

		$paramBase = ACYMAILING_COMPONENT.'.'.$this->name;

		$pageInfo->filter->order->value = acymailing_getUserVar($paramBase.".filter_order", 'filter_order', 'a.product_id', 'cmd');
		$pageInfo->filter->order->dir = acymailing_getUserVar($paramBase.".filter_order_Dir", 'filter_order_Dir', 'asc', 'word');
		if(strtolower($pageInfo->filter->order->dir) !== 'desc') $pageInfo->filter->order->dir = 'asc';
		$pageInfo->search = acymailing_getUserVar($paramBase.".search", 'search', '', 'string');
		$pageInfo->search = strtolower(trim($pageInfo->search));
		$pageInfo->filter_cat = acymailing_getUserVar($paramBase.".filter_cat", 'filter_cat', '', 'int');
		$pageInfo->filter_type = acymailing_getUserVar($paramBase.".filter_type", 'filter_type', '', 'int');
		$pageInfo->limit->value = acymailing_getUserVar($paramBase.'.list_limit', 'limit', acymailing_getCMSConfig('list_limit'), 'int');
		$pageInfo->limit->start = acymailing_getUserVar($paramBase.'.limitstart', 'limitstart', 0, 'int');
		$pageInfo->contentfilter = acymailing_getUserVar($paramBase.".contentfilter", 'contentfilter', 'created', 'string');
		$pageInfo->contentorder = acymailing_getUserVar($paramBase.".contentorder", 'contentorder', 'id,DESC', 'string');
		$pageInfo->cols = acymailing_getUserVar($paramBase.".cols", 'cols', '1', 'string');
		$pageInfo->pictheight = acymailing_getUserVar($paramBase.".pictheight", 'pictheight', '150', 'string');
		$pageInfo->pictwidth = acymailing_getUserVar($paramBase.".pictwidth", 'pictwidth', '150', 'string');
		$pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', '1', 'string');
		$pageInfo->pictauto = acymailing_getUserVar($paramBase.".autopict", 'autopict', '1', 'string');
		$pageInfo->readmore = acymailing_getUserVar($paramBase.".readmore", 'readmore', '1', 'string');
		$pageInfo->readmoreauto = acymailing_getUserVar($paramBase.".readmoreauto", 'readmoreauto', '1', 'string');
		$pageInfo->wrap = acymailing_getUserVar($paramBase.".wrap", 'wrap', '0', 'string');
		$pageInfo->clickable = acymailing_getUserVar($paramBase.".clickable", 'clickable', '1', 'string');
		$pageInfo->clickableauto = acymailing_getUserVar($paramBase.".clickableauto", 'clickableauto', '1', 'string');

		//the query's start
		$query = 'SELECT SQL_CALC_FOUND_ROWS a.product_id, a.name, b.name AS cattitle '.'FROM #__mijoshop_product_description AS a '.'JOIN #__mijoshop_product AS d ON a.product_id = d.product_id '.'JOIN #__mijoshop_product_to_category AS c ON a.product_id = c.product_id '.'JOIN #__mijoshop_category_description AS b ON b.category_id = c.category_id ';

		$filters[] = 'a.language_id = '.$this->lang_id;
		$filters[] = 'b.language_id = '.$this->lang_id;

		//search fields...
		$searchFields = array('a.name', 'a.product_id');

		//apply search fields
		if(!empty($pageInfo->search)){
			$searchVal = '\'%'.acymailing_getEscaped($pageInfo->search, true).'%\'';
			$filters[] = implode(" LIKE $searchVal OR ", $searchFields)." LIKE ".$searchVal;
		}

		//only published content ?
		if($this->params->get('displaycontent', 'all') == 'onlypub'){
			$filters[] = 'd.status = 1';
		}

		//if the user filtered by category
		if(!empty($pageInfo->filter_cat)){
			$filters[] = 'c.category_id = '.intval($pageInfo->filter_cat);
		}

		//apply filters
		if(!empty($filters)){
			$query .= ' WHERE ('.implode(') AND (', $filters).')';
		}

		$query .= ' GROUP BY a.product_id';

		//apply ordering
		if(!empty($pageInfo->filter->order->value)){
			$query .= ' ORDER BY '.$pageInfo->filter->order->value.' '.$pageInfo->filter->order->dir;
		}

		$rows = acymailing_loadObjectList($query, '', $pageInfo->limit->start, $pageInfo->limit->value);

		//yellow highlighting on search matches
		if(!empty($pageInfo->search)){
			$rows = acymailing_search($pageInfo->search, $rows);
		}

		//pagination
		$pageInfo->elements->total = acymailing_loadResult('SELECT FOUND_ROWS()');
		$pageInfo->elements->page = count($rows);

		$pagination = new acyPagination($pageInfo->elements->total, $pageInfo->limit->start, $pageInfo->limit->value);

		//is this a Smart-Newsletter or a simple one ?
		$type = acymailing_getVar('string', 'type');

		?>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedContents = new Array();
			function applyContent(contentid, rowClass){
				<?php
				//we insert contents in the order the user selected it
				?>
				var tmp = selectedContents.indexOf(contentid)
				if(tmp != -1){
					window.document.getElementById('content' + contentid).className = rowClass;
					delete selectedContents[tmp];
				}else{
					window.document.getElementById('content' + contentid).className = 'selectedrow';
					selectedContents.push(contentid);
				}
				updateTag();
			}

			var selectedCat = new Array();
			function applyAuto(catid, rowClass){
				if(catid == 'all'){
					if(window.document.getElementById('cat' + catid).className == 'selectedrow'){
						window.document.getElementById('catall').className = rowClass;
					}else{
						window.document.getElementById('cat' + catid).className = 'selectedrow';
						for(key in selectedCat){
							if(!isNaN(key)){
								window.document.getElementById('cat' + key).className = rowClass;
								delete selectedCat[key];
							}
						}
					}
				}else{
					window.document.getElementById('catall').className = 'row0';
					if(selectedCat[catid]){
						window.document.getElementById('cat' + catid).className = rowClass;
						delete selectedCat[catid];
					}else{
						window.document.getElementById('cat' + catid).className = 'selectedrow';
						selectedCat[catid] = 'selectedone';
					}
				}
				updateTagAuto();
			}

			function updateTag(){
				var tag = '';
				var otherinfo = '';
				var tmp = 0;

				<?php
				//add the fields the user wants to be displayed
				?>
				for(var i = 0; i < document.adminForm.cbdisplay.length; i++){
					if(document.adminForm.cbdisplay[i].checked){
						if(tmp == 0){
							tmp += 1;
							otherinfo += "| display:";
							otherinfo += document.adminForm.cbdisplay[i].value;
						}else{
							otherinfo += ", ";
							otherinfo += document.adminForm.cbdisplay[i].value;
						}
					}
				}

				<?php
				//is the title clickable ?
				?>
				for(var i = 0; i < document.adminForm.clickable.length; i++){
					if(document.adminForm.clickable[i].checked && document.adminForm.clickable[i].value == '0'){
						otherinfo += '| nolink';
					}
				}

				<?php
				//do we have to wrap the text ? (description for example...)
				?>
				if(document.adminForm.wrap.value && document.adminForm.wrap.value != 0 && !isNaN(document.adminForm.wrap.value)){
					otherinfo += "| wrap:" + document.adminForm.wrap.value;
				}

				if(document.adminForm.currency.value && document.adminForm.currency.value != ""){
					otherinfo += "| currency:" + document.adminForm.currency.value;
				}

				if(document.adminForm.customerGroup.value){
					otherinfo += "| customerGroup:" + document.adminForm.customerGroup.value;
				}

				<?php
				//do we have to add a "read more" button ?
				?>
				for(var i = 0; i < document.adminForm.readmore.length; i++){
					if(document.adminForm.readmore[i].checked && document.adminForm.readmore[i].value == '0'){
						otherinfo += '| noreadmore';
					}
				}

				<?php
				//picture management
				?>
				for(var i = 0; i < document.adminForm.pict.length; i++){
					if(document.adminForm.pict[i].checked){
						if(document.adminForm.pict[i].value != '1'){
							otherinfo += '| pict:' + document.adminForm.pict[i].value;
						}

						if(document.adminForm.pict[i].value == 'resized'){
							document.getElementById('pictsize').style.display = '';
							if(document.adminForm.pictwidth.value) otherinfo += '| maxwidth:' + document.adminForm.pictwidth.value;
							if(document.adminForm.pictheight.value) otherinfo += '| maxheight:' + document.adminForm.pictheight.value;
						}else{
							document.getElementById('pictsize').style.display = 'none';
						}
					}
				}

				if(window.document.getElementById('jlang') && window.document.getElementById('jlang').value != ''){
					otherinfo += '| lang:' + window.document.getElementById('jlang').value;
				}

				<?php
				//insert the tags with the right order
				?>
				for(var i in selectedContents){
					if(selectedContents[i] && !isNaN(i)){
						tag = tag + '{<?php echo $this->name; ?>:' + selectedContents[i] + otherinfo + '}<br />';
					}
				}
				setTag(tag);
			}


			function updateTagAuto(){
				var tag = '';
				var otherinfo = '';
				var tmp = 0;

				for(var i = 0; i < document.adminForm.cbdisplayauto.length; i++){
					if(document.adminForm.cbdisplayauto[i].checked){
						if(tmp == 0){
							tmp += 1;
							otherinfo += "| display:";
							otherinfo += document.adminForm.cbdisplayauto[i].value;
						}else{
							otherinfo += ", ";
							otherinfo += document.adminForm.cbdisplayauto[i].value;
						}
					}
				}

				for(var i = 0; i < document.adminForm.clickableauto.length; i++){
					if(document.adminForm.clickableauto[i].checked && document.adminForm.clickableauto[i].value == '0'){
						otherinfo += '| nolink';
					}
				}

				if(document.adminForm.wrapauto.value && document.adminForm.wrapauto.value != 0 && !isNaN(document.adminForm.wrapauto.value)){
					otherinfo += "| wrap:" + document.adminForm.wrapauto.value;
				}

				for(var i = 0; i < document.adminForm.readmoreauto.length; i++){
					if(document.adminForm.readmoreauto[i].checked && document.adminForm.readmoreauto[i].value == '0'){
						otherinfo += '| noreadmore';
					}
				}

				tmp = 0;
				for(var i = 0; i < document.adminForm.autopict.length; i++){
					if(document.adminForm.autopict[i].checked){
						if(document.adminForm.autopict[i].value != '1'){
							otherinfo += '| pict:' + document.adminForm.autopict[i].value;
						}

						if(document.adminForm.autopict[i].value == 'resized'){
							document.getElementById('pictsizeauto').style.display = '';
							if(document.adminForm.pictwidthauto.value) otherinfo += '| maxwidth:' + document.adminForm.pictwidthauto.value;
							if(document.adminForm.pictheightauto.value) otherinfo += '| maxheight:' + document.adminForm.pictheightauto.value;
						}else{
							document.getElementById('pictsizeauto').style.display = 'none';
						}
					}
				}

				if(document.adminForm.autocurrency.value && document.adminForm.autocurrency.value != ""){
					otherinfo += "| currency:" + document.adminForm.autocurrency.value;
				}

				<?php
				//on how many columns do we have to display the contents ?
				?>
				if(document.adminForm.cols.value){
					otherinfo += "| cols:" + document.adminForm.cols.value;
				}

				<?php
				//limit the number of content displayed
				?>
				if(document.adminForm.max_article.value){
					otherinfo += "| max:" + document.adminForm.max_article.value;
				}

				if(document.adminForm.autocustomerGroup.value){
					otherinfo += "| customerGroup:" + document.adminForm.autocustomerGroup.value;
				}

				<?php
				//with what order will we display the contents
				?>
				if(document.adminForm.contentorder.value){
					otherinfo += "| order:" + document.adminForm.contentorder.value;
				}

				if(window.document.getElementById('jlangauto') && window.document.getElementById('jlangauto').value != ''){
					otherinfo += '| lang:' + window.document.getElementById('jlangauto').value;
				}

				<?php if($type == 'autonews'){

				//minimum number of content for the newsletter to be displayed... yes, a perfect english !
				?>
				if(document.adminForm.min_article.value){
					otherinfo += "| min:" + document.adminForm.min_article.value;
				}

				<?php
				//filter the content : only newly created/modified
				?>
				if(document.adminForm.contentfilter && document.adminForm.contentfilter.value != 0){
					otherinfo += "| filter:" + document.adminForm.contentfilter.value;
				}
				<?php }
				//insert the tag
				?>
				tag = '{auto<?php echo $this->name; ?>:';
				for(var icat in selectedCat){
					if(selectedCat[icat] == 'selectedone'){
						tag += icat + '-';
					}
				}
				tag += otherinfo + '}<br />';

				setTag(tag);
			}
			//-->
		</script>
		<?php
		// yes/no for the options
		$choice = array();
		$choice[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$choice[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		// picture options
		$valImages = array();
		$valImages[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$valImages[] = acymailing_selectOption("resized", acymailing_translation('RESIZED'));
		$valImages[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		// here are the possible orderings
		$ordering = array();
		$ordering[] = acymailing_selectOption("product_id,DESC", acymailing_translation('ACY_ID'));
		$ordering[] = acymailing_selectOption("date_added,DESC", acymailing_translation('CREATED_DATE'));
		$ordering[] = acymailing_selectOption("date_modified,DESC", acymailing_translation('MODIFIED_DATE'));
		$ordering[] = acymailing_selectOption("name,ASC", acymailing_translation('FIELD_TITLE'));
		$ordering[] = acymailing_selectOption("rand", acymailing_translation('ACY_RANDOM'));

		// filter options
		$contentfilter = array();
		$contentfilter[] = acymailing_selectOption("0", acymailing_translation('ACY_ALL'));
		$contentfilter[] = acymailing_selectOption("created", acymailing_translation('ONLY_NEW_CREATED'));
		$contentfilter[] = acymailing_selectOption("modified", acymailing_translation('ONLY_NEW_MODIFIED'));

		// options for the Nb. columns dropdown (1 to 10)
		$column = array();
		for($i = 1; $i < 11; $i++){
			$column[] = acymailing_selectOption("$i", $i);
		}

		if(ACYMAILING_J30){
			$paginationNb = array();
			$paginationNb[] = acymailing_selectOption(5, 5);
			$paginationNb[] = acymailing_selectOption(10, 10);
			$paginationNb[] = acymailing_selectOption(15, 15);
			$paginationNb[] = acymailing_selectOption(20, 20);
			$paginationNb[] = acymailing_selectOption(25, 25);
			$paginationNb[] = acymailing_selectOption(30, 30);
			$paginationNb[] = acymailing_selectOption(50, 50);
			$paginationNb[] = acymailing_selectOption(100, 100);
			$paginationNb[] = acymailing_selectOption(0, acymailing_translation('ACY_ALL'));
		}

		$fieldsDisplay = array();
		$fieldsDisplay[] = array('title' => 'title', 'label' => 'ACY_TITLE', 'checked' => 'yes');
		$fieldsDisplay[] = array('title' => 'image', 'label' => 'ACY_IMAGE', 'checked' => 'yes');
		$fieldsDisplay[] = array('title' => 'description', 'label' => 'ACY_DESCRIPTION', 'checked' => 'yes');
		$fieldsDisplay[] = array('title' => 'code', 'label' => 'COM_MIJOSHOP_PRODUCT_PRODUCT_TEXT_MODEL', 'checked' => '');
		$fieldsDisplay[] = array('title' => 'avail', 'label' => 'COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_AVAILABILITY', 'checked' => '');
		$fieldsDisplay[] = array('title' => 'rate', 'label' => 'COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_RATING', 'checked' => '');
		$fieldsDisplay[] = array('title' => 'price', 'label' => 'COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_PRICE', 'checked' => 'yes');
		$fieldsDisplay[] = array('title' => 'pltax', 'label' => 'COM_MIJOSHOP_PRODUCT_CATEGORY_TEXT_TAX', 'checked' => '');
		$fieldsDisplay[] = array('title' => 'discounts', 'label' => 'Discounts', 'checked' => '');

		$customerGroups = acymailing_loadObjectList('SELECT customer_group_id, name FROM #__mijoshop_customer_group_description WHERE language_id = '.$this->lang_id.'', 'customer_group_id');
		$query = 'SELECT customer_group_id, name FROM #__mijoshop_customer_group_description WHERE customer_group_id NOT IN ('.implode(',', array_merge(array_keys($customerGroups), array(-1))).') GROUP BY customer_group_id';
		$customerGroups = array_merge($customerGroups, acymailing_loadObjectList($query, 'customer_group_id'));

		$currency = acymailing_loadObjectList('SELECT title, code FROM #__mijoshop_currency WHERE status = 1 ORDER BY title ASC');
		$default = new stdClass();
		$default->title = '- - -';
		$default->code = '';
		$currency = array_merge(array($default), $currency);

		$tabs = acymailing_get('helper.acytabs');
		echo $tabs->startPane($this->name.'_tab');
		echo $tabs->startPanel(acymailing_translation('ACY_PRODUCTS'), $this->name.'_listings');
		?>
		<br style="font-size:1px"/>
		<table width="100%" class="adminform">
			<tr>
				<?php
				// what should we display ?
				?>
				<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY'); ?></td>
				<?php
				$i = 1;
				foreach($fieldsDisplay as $oneField){
					if($i % 5 == 0){
						echo '</tr><tr><td/>';
						$i++;
					}
					if($i == 4){
						$jflanguages = acymailing_get('type.jflanguages');
						$jflanguages->onclick = 'onchange="updateTag();"';
						$jflanguages->jid = 'jlang';
						echo '<td>'.$jflanguages->displayJLanguages('jlang').'</td></tr><tr><td/>';
						$i += 2;
					}
					echo '<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="'.$oneField['title'].'" id="'.$oneField['title'].'" '.(($oneField['checked'] == 'yes') ? 'checked' : '').' onclick="updateTag();"/><label style="margin-left:5px" for="'.$oneField['title'].'">'.trim(acymailing_translation($oneField['label']), ':').'</label></td>';
					$i++;
				}
				while($i % 5 != 0){
					echo '<td/>';
					$i++;
				}
				?>
			</tr>
			<tr>
				<td><?php echo acymailing_translation('COM_MIJOSHOP_MODULE_CURRENCY_TEXT_CURRENCY'); ?></td>
				<td colspan="2">
					<?php echo acymailing_select($currency, 'currency', 'size="1" onchange="updateTag();" style="width:100px;"', 'code', 'title'); ?>
				</td>
				<td><?php echo trim(acymailing_translation('COM_MIJOSHOP_MAIL_CUSTOMER_TEXT_CUSTOMER_GROUP'), ':').'<small> (for price)</small>'; ?></td>
				<td>
					<?php echo acymailing_select($customerGroups, 'customerGroup', 'size="1" onchange="updateTag();" style="width:100px;"', 'customer_group_id', 'name'); ?>
				</td>
			</tr>
			<tr>
				<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
				<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($choice, 'clickable', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->clickable); ?></td>

				<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
				<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmore', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->readmore); ?>
			</tr>
			<tr>
				<td nowrap="nowrap" valign="top"><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
				<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($valImages, 'pict', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->pict); ?>
					<span id="pictsize" <?php if($pageInfo->pict != 'resized') echo 'style="display:none;"'; ?> ><br/>
						<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
						<input name="pictwidth" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
						x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
						<input name="pictheight" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
					</span>
				</td>
				<td nowrap="nowrap" colspan="2" valign="top"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrap" style="width:50px" value="0" onchange="updateTag();"/>'); ?></td>
			</tr>
		</table>
		<table>
			<tr>
				<td nowrap="nowrap" width="100%">
					<input placeholder="<?php echo acymailing_translation('ACY_SEARCH'); ?>" type="text" name="search" id="acymailingsearch" value="<?php echo $pageInfo->search; ?>" class="text_area" onchange="document.adminForm.submit();"/>
					<button class="btn" onclick="this.form.submit();"><?php echo acymailing_translation('JOOMEXT_GO'); ?></button>
					<button class="btn" onclick="document.getElementById('acymailingsearch').value='';this.form.submit();"><?php echo acymailing_translation('JOOMEXT_RESET'); ?></button>
				</td>
				<td nowrap="nowrap">
					<?php echo $this->_categories($pageInfo->filter_cat); ?>
				</td>
			</tr>
		</table>
		<table class="adminlist table table-striped table-hover" cellpadding="1" width="100%">
			<thead>
			<tr>
				<th/>
				<th class="title">
					<?php
					echo acymailing_gridSort(acymailing_translation('FIELD_TITLE'), 'a.name', $pageInfo->filter->order->dir, $pageInfo->filter->order->value);
					?>
				</th>
				<th class="title">
					<?php echo acymailing_gridSort(acymailing_translation('TAG_CATEGORIES'), 'b.name', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
				</th>
				<th class="title titleid">
					<?php
					echo acymailing_gridSort(acymailing_translation('ACY_ID'), 'a.product_id', $pageInfo->filter->order->dir, $pageInfo->filter->order->value);
					?>
				</th>
			</tr>
			</thead>
			<tfoot>
			<tr>
				<td colspan="5">
					<?php
					echo $pagination->getListFooter();
					if(ACYMAILING_J30){
						echo 'Display #'.acymailing_select($paginationNb, 'limit', 'size="1" style="width:60px" onchange="acymailing.submitform();"', 'value', 'text', $pageInfo->limit->value).'<br />';
					}
					echo $pagination->getResultsCounter();
					?>
				</td>
			</tr>
			</tfoot>
			<tbody>
			<?php
			$k = 0;
			if(!empty($rows)){
				foreach($rows as $row){
					?>
					<tr id="content<?php echo $row->product_id; ?>" class="<?php echo "row$k"; ?>" onclick="applyContent(<?php echo $row->product_id.",'row$k'" ?>);" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td style="text-align:center;">
							<?php
							echo $row->name;
							?>
						</td>
						<td style="text-align:center;">
							<?php
							echo $row->cattitle;
							?>
						</td>
						<td style="text-align:center;">
							<?php
							echo $row->product_id;
							?>
						</td>
					</tr>
					<?php
					// this enables to know if we have to set the line background grey or white
					$k = 1 - $k;
				}
			}
			?>
			</tbody>
		</table>
		<input type="hidden" name="boxchecked" value="0"/>
		<input type="hidden" name="filter_order" value="<?php echo $pageInfo->filter->order->value; ?>"/>
		<input type="hidden" name="filter_order_Dir" value="<?php echo $pageInfo->filter->order->dir; ?>"/>

		<?php
		echo $tabs->endPanel();
		echo $tabs->startPanel(acymailing_translation('TAG_CATEGORIES'), $this->name.'_auto');
		?>

		<br style="font-size:1px"/>
		<table width="100%" class="adminform">
			<tr>
				<?php
				// what should we display ?
				?>
				<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY'); ?></td>
				<?php
				$i = 1;
				foreach($fieldsDisplay as $oneField){
					if($i % 5 == 0){
						echo '</tr><tr><td/>';
						$i++;
					}
					if($i == 4){
						$jflanguages = acymailing_get('type.jflanguages');
						$jflanguages->onclick = 'onchange="updateTagAuto();"';
						$jflanguages->jid = 'jlangauto';
						echo '<td>'.$jflanguages->displayJLanguages('jlangauto').'</td></tr><tr><td/>';
						$i += 2;
					}
					echo '<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="'.$oneField['title'].'" id="'.$oneField['title'].'auto" '.(($oneField['checked'] == 'yes') ? 'checked' : '').' onclick="updateTagAuto();"/><label style="margin-left:5px" for="'.$oneField['title'].'auto">'.trim(acymailing_translation($oneField['label']), ':').'</label></td>';
					$i++;
				}
				while($i % 5 != 0){
					echo '<td/>';
					$i++;
				}
				?>
			</tr>
			<tr>
				<td><?php echo acymailing_translation('COM_MIJOSHOP_MODULE_CURRENCY_TEXT_CURRENCY'); ?></td>
				<td colspan="2">
					<?php echo acymailing_select($currency, 'autocurrency', 'size="1" onchange="updateTagAuto();" style="width:100px;"', 'code', 'title'); ?>
				</td>
				<td><?php echo trim(acymailing_translation('COM_MIJOSHOP_MAIL_CUSTOMER_TEXT_CUSTOMER_GROUP'), ':').'<small> (for price)</small>'; ?></td>
				<td>
					<?php echo acymailing_select($customerGroups, 'autocustomerGroup', 'size="1" onchange="updateTagAuto();" style="width:100px;"', 'customer_group_id', 'name'); ?>
				</td>
			</tr>
			<tr>
				<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
				<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($choice, 'clickableauto', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->clickableauto); ?></td>
				<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
				<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmoreauto', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->readmoreauto); ?>
			</tr>
			<tr>
				<td nowrap="nowrap" valign="top">
					<?php echo acymailing_translation('DISPLAY_PICTURES'); ?>
				</td>
				<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($valImages, 'autopict', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->pictauto); ?>
					<span id="pictsizeauto" <?php if($pageInfo->pictauto != 'resized') echo 'style="display:none;"'; ?> ><br/>
						<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
						<input name="pictwidthauto" type="text" onchange="updateTagAuto();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
						x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
						<input name="pictheightauto" type="text" onchange="updateTagAuto();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
					</span>
				</td>
				<td nowrap="nowrap" colspan="2" valign="top"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrapauto" style="width:50px" value="0" onchange="updateTagAuto();"/>'); ?></td>
			</tr>
			<tr>
				<td nowrap="nowrap" nowrap="nowrap">
					<?php echo acymailing_translation('MAX_ARTICLE'); ?>
				</td>
				<td nowrap="nowrap" colspan="2">
					<input type="text" name="max_article" style="width:50px" value="20" onchange="updateTagAuto();"/>
				</td>
				<td nowrap="nowrap">
					<?php echo acymailing_translation('ACY_ORDER'); ?>
				</td>
				<td nowrap="nowrap">
					<?php echo acymailing_select($ordering, 'contentorder', 'size="1" onchange="updateTagAuto();" style="width:100px;"', 'value', 'text', $pageInfo->contentorder); ?>
				</td>
			</tr>
			<?php if($type == 'autonews'){ ?>
				<tr>
					<td nowrap="nowrap">
						<?php echo acymailing_translation('MIN_ARTICLE'); ?>
					</td nowrap="nowrap">
					<td nowrap="nowrap" colspan="2">
						<input type="text" name="min_article" style="width:50px" value="1" onchange="updateTagAuto();"/>
					</td>
					<td>
						<?php echo acymailing_translation('FIELD_COLUMNS'); ?>
					</td>
					<td nowrap="nowrap">
						<?php echo acymailing_select($column, 'cols', 'size="1" onchange="updateTagAuto();" style="width:100px;"', 'value', 'text', $pageInfo->cols); ?>
					</td>
				</tr>
				<tr>
					<td nowrap="nowrap">
						<?php echo acymailing_translation('JOOMEXT_FILTER'); ?>
					</td>
					<td nowrap="nowrap" colspan="4">
						<?php echo acymailing_select($contentfilter, 'contentfilter', 'size="1" onchange="updateTagAuto();"', 'value', 'text', $pageInfo->contentfilter); ?>
					</td>
				</tr>
			<?php }else{ ?>
				<tr>
					<td nowrap="nowrap">
						<?php echo acymailing_translation('FIELD_COLUMNS'); ?>
					</td>
					<td nowrap="nowrap" colspan="4">
						<?php echo acymailing_select($column, 'cols', 'size="1" onchange="updateTagAuto();" style="width:100px;"', 'value', 'text', $pageInfo->cols); ?>
					</td>
				</tr>
			<?php } ?>
		</table>
		<!--====================================================================================LISTE CATEGORIES===========================================================================-->
		<table class="adminlist table table-striped table-hover" cellpadding="1" width="100%">
			<?php
			$k = 0;
			?>
			<tr id="catall" class="<?php echo "row$k"; ?>" onclick="applyAuto('all','<?php echo "row$k" ?>');" style="cursor:pointer;">
				<td class="acytdcheckbox"></td>
				<td>
					<?php
					echo acymailing_translation('ACY_ALL');
					?>
				</td>
			</tr>
			<?php
			if(!empty($this->catvalues)){
				foreach($this->catvalues as $oneCat){
					if(empty($oneCat->value)) continue;
					?>
					<tr id="cat<?php echo $oneCat->value ?>" class="<?php echo "row$k"; ?>" onclick="applyAuto(<?php echo $oneCat->value ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td>
							<?php
							echo $oneCat->text;
							?>
						</td>
					</tr>
					<?php
					$k = 1 - $k;
				}
			}
			?>
		</table>
		<?php
		echo $tabs->endPanel();
		echo $tabs->endPane();
	}

	function _categories($filter_cat){
		//select all cats
		$mosetCats = acymailing_loadObjectList('SELECT a.category_id AS id, a.parent_id, b.name AS title '.'FROM #__mijoshop_category AS a '.'JOIN #__mijoshop_category_description AS b '.'ON a.category_id = b.category_id '.'WHERE b.language_id = '.$this->lang_id, 'id');
		$query = 'SELECT a.category_id AS id, a.parent_id, b.name AS title '.'FROM #__mijoshop_category AS a '.'JOIN #__mijoshop_category_description AS b '.'ON a.category_id = b.category_id '.'WHERE a.category_id NOT IN ('.implode(',', array_merge(array_keys($mosetCats), array(-1))).') GROUP BY a.category_id';
		$mosetCats = array_merge($mosetCats, acymailing_loadObjectList($query, 'id'));
		$this->cats = array();
		if(!empty($mosetCats)){
			foreach($mosetCats as $oneCat){
				$this->cats[$oneCat->parent_id][] = $oneCat;
			}
		}

		$this->catvalues = array();
		$this->catvalues[] = acymailing_selectOption(0, acymailing_translation('ACY_ALL'));
		$this->_handleChildrens();
		return acymailing_select($this->catvalues, 'filter_cat', 'class="inputbox" size="1" onchange="document.adminForm.submit( );"', 'value', 'text', intval($filter_cat));
	}

	function _handleChildrens($parent_id = 0, $level = 0){
		if(!empty($this->cats[$parent_id])){
			foreach($this->cats[$parent_id] as $cat){
				$this->catvalues[] = acymailing_selectOption($cat->id, str_repeat(" - - ", $level).$cat->title);
				$this->_handleChildrens($cat->id, $level + 1);
			}
		}
	}

	function acymailing_replacetags(&$email){
		$this->_replaceAuto($email);
		$this->_replaceOne($email);
	}

	function _replaceOne(&$email){
		$acypluginsHelper = acymailing_get('helper.acyplugins');

		//load the tags
		$tags = $acypluginsHelper->extractTags($email, $this->name);
		if(empty($tags)) return;

		$this->newslanguage = new stdClass();
		if(!empty($email->language)){
			$this->newslanguage = acymailing_loadObject('SELECT lang_id, lang_code FROM #__languages WHERE sef = '.acymailing_escapeDB($email->language).' LIMIT 1');
		}

		
		acymailing_loadLanguageFile('com_mijoshop', JPATH_SITE);

		//We will need the mailer class as well
		$this->mailerHelper = acymailing_get('helper.mailer');

		//Set the read more text or image
		$this->readmore = empty($email->template->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : '<img src="'.ACYMAILING_LIVE.$email->template->readmore.'" alt="'.acymailing_translation('JOOMEXT_READ_MORE', true).'" />';

		$htmlreplace = array();
		$textreplace = array();
		$subjectreplace = array();
		foreach($tags as $i => $params){
			if(isset($htmlreplace[$i])) continue;
			$content = $this->_replaceContent($tags[$i]);
			$htmlreplace[$i] = $content;
			$textreplace[$i] = $this->mailerHelper->textVersion($content, true);
			$subjectreplace[$i] = strip_tags($content);
		}
		$email->body = str_replace(array_keys($htmlreplace), $htmlreplace, $email->body);
		$email->altbody = str_replace(array_keys($textreplace), $textreplace, $email->altbody);
		$email->subject = str_replace(array_keys($subjectreplace), $subjectreplace, $email->subject);
	}

	function _replaceContent(&$tag){
		$acypluginsHelper = acymailing_get('helper.acyplugins');

		// extract the fields selected
		if(!empty($tag->display)){
			$tag->display = explode(',', $tag->display);

			foreach($tag->display as $i => $oneDisplay){
				$oneDisplay = trim($oneDisplay);
				$tag->$oneDisplay = true;
			}
			unset($tag->display);
		}
		if(empty($tag->customerGroup)) $tag->customerGroup = -1;

		// load content
		$query = 'SELECT a.*, b.name, b.description, c.name AS stock '.'FROM #__mijoshop_product AS a '.'JOIN #__mijoshop_product_description AS b ON a.product_id = b.product_id '.'JOIN #__mijoshop_stock_status AS c ON a.stock_status_id = c.stock_status_id ';

		$where = array();
		$whereSafe = array();
		$where[] = 'a.product_id = '.intval($tag->id);
		$whereSafe[] = 'a.product_id = '.intval($tag->id);

		if(!empty($tag->lang) && (empty($this->newslanguage) || empty($this->newslanguage->lang_code) || $this->newslanguage->lang_code != $tag->lang)){
			$lang_id = acymailing_loadResult('SELECT lang_id FROM #__languages WHERE lang_code = '.acymailing_escapeDB($tag->lang));
			$lang_id = intval($lang_id);
		}elseif(!empty($this->newslanguage)){
			$lang_id = $this->newslanguage->lang_id;
		}

		if(!empty($lang_id)){
			$where[] = 'b.language_id = '.$lang_id;
			$where[] = 'c.language_id = '.$lang_id;
			$whereSafe[] = 'b.language_id = '.$lang_id;
		}else{
			$where[] = 'b.language_id = '.$this->lang_id;
			$where[] = 'c.language_id = '.$this->lang_id;
			$whereSafe[] = 'b.language_id = '.$this->lang_id;
		}

		$query .= ' WHERE ('.implode(') AND (', $where).') LIMIT 1';
		$content = acymailing_loadObject($query);

		//In case of we could not load the article for any reason...
		if(empty($content)){
			$query = 'SELECT a.*, b.name, b.description FROM #__mijoshop_product AS a JOIN #__mijoshop_product_description AS b ON a.product_id = b.product_id WHERE ('.implode(') AND (', $whereSafe).') LIMIT 1';
			$content = acymailing_loadObject($query);

			if(empty($content)){
				if(acymailing_isAdmin()){
					acymailing_enqueueMessage('The product "'.$tag->id.'" could not be loaded', 'notice');
				}
				return '';
			}
		}

		$varFields = array();
		foreach($content as $fieldName => $oneField){
			$varFields['{'.$fieldName.'}'] = $oneField;
		}

		// create the link for the title and the read more button
		$link = ACYMAILING_LIVE.'index.php?option=com_mijoshop&route=product/product&product_id='.$tag->id;
		if(!empty($tag->itemid)) $link .= '&Itemid='.$tag->itemid;

		$varFields['{link}'] = $link;

		$result = '<div class="acymailing_content"><table cellspacing="0" cellpadding="0" border="0" width="100%">';

		// display the title
		if(!empty($tag->title)){
			$result .= '<tr><td colspan="2"><h2 class="acymailing_title">';
			if(empty($tag->nolink)){
				$result .= '<a href="'.$link.'">';
			}
			$result .= $content->name;
			if(empty($tag->nolink)){
				$result .= '</a>';
			}
			$result .= '</h2></td></tr>';
		}

		// display the main text wraped or not
		if(!((empty($tag->image) || empty($content->image)) && (empty($tag->description) || empty($content->description)))){
			$result .= '<tr><td colspan="2" style="text-align:justify;">';
			if(!empty($tag->image) && !empty($content->image)){
				$varFields['{imagepath}'] = $content->image;
				$varFields['{image}'] = '<img style="float:left;" src="components/com_mijoshop/opencart/image/'.$content->image.'"/>';
				$result .= $varFields['{image}'];
			}

			if(!empty($tag->description) && !empty($content->description)){
				$varFields['{description}'] = str_replace(array('&lt;', '&gt;', '&amp;', '&quot;'), array('<', '>', '&', '"'), $content->description);
				$result .= $acypluginsHelper->wrapText($varFields['{description}'], $tag);
			}
			$result .= '</td></tr>';
		}

		$fields = array();

		// Get the first special price available
		$specialPrice = acymailing_loadResult('SELECT price '.'FROM #__mijoshop_product_special '.'WHERE product_id = '.intval($content->product_id).' '.'AND customer_group_id = '.intval($tag->customerGroup).' '.'AND (date_start LIKE "0000-00-00" OR date_start <= \''.date('Y-m-d').'\') '.'AND (date_end LIKE "0000-00-00" OR date_end >= \''.date('Y-m-d').'\') '.'ORDER BY priority ASC');
		if(!empty($specialPrice)){
			$oldPrice = $content->price;
			$content->price = $specialPrice;
		}

		if(!empty($tag->currency)){
			$currencyTag = $tag->currency;
		}elseif($this->params->get('currency', 'default') != 'default'){
			$currencyTag = $this->params->get('currency', 'default');
		}

		if(!empty($currencyTag)){
			$currency = acymailing_loadObject('SELECT * FROM #__mijoshop_currency WHERE code LIKE '.acymailing_escapeDB($currencyTag));
		}

		if(empty($currency)){
			$currency = new stdClass();
			$currency->value = 1.0;
			$currency->symbol_left = '$';
			$currency->symbol_right = '';
			$currency->decimal_place = 2;
			$currency->decimal_separator = '.';
		}else{
			$currency->decimal_separator = ',';
		}

		$content->price = $content->price * $currency->value;

		if(!empty($tag->price) && !empty($content->price)){
			$tax = acymailing_loadObject('SELECT a.rate, a.type '.'FROM #__mijoshop_tax_rate AS a '.'JOIN #__mijoshop_tax_rule AS b ON a.tax_rate_id = b.tax_rate_id '.'JOIN #__mijoshop_tax_rate_to_customer_group AS c ON a.tax_rate_id = c.tax_rate_id AND c.customer_group_id = '.intval($tag->customerGroup).' '.'WHERE b.tax_class_id = '.intval($content->tax_class_id).' '.'ORDER BY b.priority ASC');
			$price = $content->price;
			if(!empty($oldPrice)){
				if(!empty($tax)){
					if($tax->type == 'P'){
						$oldPrice = $oldPrice + ($oldPrice * ($tax->rate / 100));
					}else{
						$oldPrice = $oldPrice + $tax->rate;
					}
				}
				$oldPrice = $currency->symbol_left.number_format($oldPrice * $currency->value, $currency->decimal_place, $currency->decimal_separator, ' ').$currency->symbol_right;
				$varFields['{oldPrice}'] = $oldPrice;
			}

			if(!empty($tax)){
				if($tax->type == 'P'){
					$price = $price + ($price * ($tax->rate / 100));
				}else{
					$price = $price + $tax->rate;
				}
			}
			$price = $currency->symbol_left.number_format($price, $currency->decimal_place, $currency->decimal_separator, ' ').$currency->symbol_right;
			$varFields['{price}'] = $price;
			$fields[] = acymailing_translation('COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_PRICE').' : <strong>'.(!empty($oldPrice) ? '<strike>'.$oldPrice.'</strike> ' : '').$price.'</strong>';
		}

		if(!empty($tag->pltax) && !empty($content->price)){
			$price = $currency->symbol_left.number_format($content->price, $currency->decimal_place, $currency->decimal_separator, ' ').$currency->symbol_right;
			$varFields['{priceextax}'] = $price;
			$fields[] = '<strong>'.trim(acymailing_translation('COM_MIJOSHOP_PRODUCT_PRODUCT_TEXT_TAX'), ':').' : </strong>'.$price;
		}

		if(!empty($tag->discounts)){
			// Get the first special price if exists
			$discounts = acymailing_loadObjectList('SELECT * '.'FROM #__mijoshop_product_discount '.'WHERE product_id = '.intval($content->product_id).' '.'AND customer_group_id = '.intval($tag->customerGroup).' '.'AND (date_start LIKE "0000-00-00" OR UNIX_TIMESTAMP(date_start) < '.time().') '.'AND (date_end LIKE "0000-00-00" OR UNIX_TIMESTAMP(date_end) > '.time().') '.'ORDER BY priority ASC');
			if(!empty($discounts)){
				$listing = '';
				foreach($discounts as $oneDiscount){
					$listing .= acymailing_translation_sprintf('COM_MIJOSHOP_PRODUCT_PRODUCT_TEXT_DISCOUNT', $oneDiscount->quantity, $currency->symbol_left.number_format($oneDiscount->price * $currency->value, $currency->decimal_place, ',', ' ').$currency->symbol_right).'<br />';
				}
				$fields[] = $listing;
			}
		}

		if(!empty($tag->rate)){
			$rate = acymailing_loadResult('SELECT SUM(rating)/SUM(status) FROM #__mijoshop_review WHERE product_id = '.intval($tag->id).' AND status = 1');
			if(!empty($rate)){
				$varFields['{rate}'] = number_format($rate, 2, ',', '');
				$fields[] = '<strong>'.acymailing_translation('COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_RATING').' : </strong>'.number_format($rate, 2, ',', '').'/5';
			}
		}

		if(!empty($tag->code) && !empty($content->model)){
			$fields[] = '<strong>'.acymailing_translation('COM_MIJOSHOP_PRODUCT_PRODUCT_TEXT_MODEL').' </strong>'.$content->model;
		}

		if(!empty($tag->avail) && isset($content->quantity)){
			if(!empty($content->quantity)){
				$fields[] = '<strong>'.acymailing_translation('COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_AVAILABILITY').' : </strong>'.acymailing_translation('COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_INSTOCK');
			}else{
				if(!empty($content->stock_status_id)){
					$status = acymailing_loadObjectList('SELECT name, language_id FROM #__mijoshop_stock_status WHERE stock_status_id = '.intval($content->stock_status_id), 'language_id');
					if(!empty($status)){
						if(!empty($lang_id) && !empty($status[$lang_id])){
							$fields[] = '<strong>'.acymailing_translation('COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_AVAILABILITY').' : </strong>'.$status[$lang_id]->name;
						}elseif(!empty($status[$this->lang_id])) $fields[] = '<strong>'.acymailing_translation('COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_AVAILABILITY').' : </strong>'.$status[$this->lang_id]->name;
						else $fields[] = '<strong>'.acymailing_translation('COM_MIJOSHOP_PRODUCT_COMPARE_TEXT_AVAILABILITY').' : </strong>'.reset($status)->name;
					}
				}
			}
		}

		if(!empty($fields)){
			$result .= '<tr>';
			$i = 1;
			foreach($fields as $oneField){
				if($i % 2 == 1 && $i != 1){
					$result .= '</tr><tr>';
				}
				$result .= '<td>'.$oneField.'</td>';
				$i++;
			}
			if($i % 2 == 0){
				$result .= '<td/>';
			}
			$result .= '</tr>';
		}

		if(empty($tag->noreadmore)){
			$result .= '<tr><td colspan="2"><br /><a style="text-decoration:none;" target="_blank" href="'.$link.'"><span class="acymailing_readmore">'.$this->readmore.'</span></a></td></tr>';
		}

		$result .= '</table></div><br />';

		// load the custom template if exists
		if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.$this->name.'.php')){
			ob_start();
			require(ACYMAILING_MEDIA.'plugins'.DS.$this->name.'.php');
			$result = ob_get_clean();
			$result = str_replace(array_keys($varFields), $varFields, $result);
		}

		// always remove JS, there is no JS in newsletters...
		$result = $acypluginsHelper->removeJS($result);

		//resize or remove pictures
		$pictureHelper = acymailing_get('helper.acypict');
		if(isset($tag->pict)){
			if($tag->pict == 'resized'){
				$pictureHelper->maxHeight = empty($tag->maxheight) ? 150 : $tag->maxheight;
				$pictureHelper->maxWidth = empty($tag->maxwidth) ? 150 : $tag->maxwidth;
				if($pictureHelper->available()){
					$result = $pictureHelper->resizePictures($result);
				}elseif(acymailing_isAdmin()){
					acymailing_enqueueMessage($pictureHelper->error, 'notice');
				}
			}else{
				$result = $pictureHelper->removePictures($result);
			}
		}
		return $result;
	}

	function _replaceAuto(&$email){
		$this->acymailing_generateautonews($email);

		if(!empty($this->tags)){
			$email->body = str_replace(array_keys($this->tags), $this->tags, $email->body);

			if(!empty($email->altbody)){
				$email->altbody = str_replace(array_keys($this->tags), $this->tags, $email->altbody);
			}

			foreach($this->tags as $tag => $result){
				$email->subject = str_replace($tag, strip_tags(preg_replace('#</tr>[^<]*<tr[^>]*>#Uis', ' | ', $result)), $email->subject);
			}
		}
	}

	function acymailing_generateautonews(&$email){
		$acypluginsHelper = acymailing_get('helper.acyplugins');

		//load the tags
		$tags = $acypluginsHelper->extractTags($email, 'auto'.$this->name);
		$return = new stdClass();
		$return->status = true;
		$return->message = '';
		$this->tags = array();

		if(empty($tags)) return $return;

		foreach($tags as $oneTag => $parameter){
			if(isset($this->tags[$oneTag])) continue;

			$allcats = explode('-', $parameter->id);
			$selectedArea = array();
			foreach($allcats as $oneCat){
				if(empty($oneCat)) continue;
				$selectedArea[] = intval($oneCat);
			}

			$query = 'SELECT DISTINCT a.product_id '.'FROM #__mijoshop_product AS a '.'JOIN #__mijoshop_product_to_category AS b '.'ON a.product_id = b.product_id '.'JOIN #__mijoshop_product_description AS c '.'ON a.product_id = c.product_id ';

			$where = array();

			// load only needed content
			if(!empty($selectedArea)) $where[] = 'b.category_id IN ('.implode(',', $selectedArea).')';

			// filter results created or modified
			if(!empty($parameter->filter) && !empty($email->params['lastgenerateddate'])){
				if($parameter->filter == 'created'){
					$where[] = 'a.date_added > \''.date('Y-m-d H:i:s', $email->params['lastgenerateddate'] - date('Z')).'\'';
				}elseif($parameter->filter == 'modified'){
					$where[] = 'a.date_added > \''.date('Y-m-d H:i:s', $email->params['lastgenerateddate'] - date('Z')).'\' OR a.date_modified > \''.date('Y-m-d H:i:s', $email->params['lastgenerateddate'] - date('Z')).'\'';
				}
			}

			// Only published content
			$where[] = 'a.status = 1';

			if(!empty($parameter->lang)){
				$res = acymailing_loadResult('SELECT lang_id FROM #__languages WHERE lang_code = '.acymailing_escapeDB($parameter->lang));
				$where[] = 'c.language_id = '.intval($res);
			}

			// Apply filters
			if(!empty($where)) $query .= ' WHERE ('.implode(') AND (', $where).')';

			// Ordering
			if(!empty($parameter->order)){
				if($parameter->order == 'rand'){
					$query .= ' ORDER BY rand()';
				}elseif($parameter->order == 'name,ASC'){
					$ordering = explode(',', $parameter->order);
					$query .= ' ORDER BY c.'.acymailing_secureField(trim($ordering[0])).' '.acymailing_secureField(trim($ordering[1]));
				}else{
					$ordering = explode(',', $parameter->order);
					$query .= ' ORDER BY a.'.acymailing_secureField(trim($ordering[0])).' '.acymailing_secureField(trim($ordering[1]));
				}
			}

			// If there is no limit, then we add one
			if(!empty($parameter->max)){
				$query .= ' LIMIT '.intval($parameter->max);
			}else $query .= ' LIMIT 20'; // limit, because we do not want to display one bilion of content in the newsletter...

			// load content IDs
			$allArticles = acymailing_loadResultArray($query);

			// Check the number of results
			if(!empty($parameter->min) && count($allArticles) < $parameter->min){
				//We will not generate the Newsletter
				$return->status = false;
				$return->message = 'Not enough '.$this->name.' products for the tag '.$oneTag.' : '.count($allArticles).' / '.$parameter->min;
			}

			$stringTag = '';
			if(!empty($allArticles)){
				// If the user created its own template...
				if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'auto'.$this->name.'.php')){
					ob_start();
					require(ACYMAILING_MEDIA.'plugins'.DS.'auto'.$this->name.'.php');
					$stringTag = ob_get_clean();
				}else{
					//we insert the tags one after the other in a table as they are already sorted (using |cols parameter)
					$arrayElements = array();
					foreach($allArticles as $oneArticleId){
						$args = array();
						$args[] = $this->name.':'.$oneArticleId;
						if(!empty($parameter->nolink)) $args[] = 'nolink';
						if(!empty($parameter->noreadmore)) $args[] = 'noreadmore';
						if(!empty($parameter->wrap)) $args[] = 'wrap:'.$parameter->wrap;
						if(!empty($parameter->display)) $args[] = 'display:'.$parameter->display;
						if(!empty($parameter->currency)) $args[] = 'currency:'.$parameter->currency;
						if(isset($parameter->pict)) $args[] = 'pict:'.$parameter->pict;
						if(!empty($parameter->maxwidth)) $args[] = 'maxwidth:'.$parameter->maxwidth;
						if(!empty($parameter->maxheight)) $args[] = 'maxheight:'.$parameter->maxheight;
						if(!empty($parameter->custom)) $args[] = 'custom:'.$parameter->custom;
						if(!empty($parameter->itemid)) $args[] = 'itemid:'.$parameter->itemid;
						if(!empty($parameter->lang)) $args[] = 'lang:'.$parameter->lang;
						if(!empty($parameter->customerGroup)) $args[] = 'customerGroup:'.$parameter->customerGroup;
						$arrayElements[] = '{'.implode('|', $args).'}';
					}
					$stringTag = $acypluginsHelper->getFormattedResult($arrayElements, $parameter);
				}
			}
			$this->tags[$oneTag] = $stringTag;
		}
		return $return;
	}

	function onAcyDisplayFilters(&$type, $context = "massactions"){
		if(!$this->component_installed) return;

		acymailing_loadLanguageFile('com_mijoshop', JPATH_SITE);
		$return = '';

		//Load products
		$allProducts = acymailing_loadObjectList('SELECT product_id as value, CONCAT(product_id," : ",name) as text FROM #__mijoshop_product_description WHERE language_id = '.$this->lang_id.' ORDER BY product_id ASC');
		if(!empty($allProducts)){
			$selectOne = new stdClass();
			$selectOne->value = 0;
			$selectOne->text = acymailing_translation('ACY_ONE_PRODUCT');
			array_unshift($allProducts, $selectOne);
		}

		//Bought or not
		$buy = array();
		$buy[] = acymailing_selectOption('0', acymailing_translation('ACY_DIDNOTBOUGHT'));
		$buy[] = acymailing_selectOption('1', acymailing_translation('ACY_BOUGHT'));

		//Load status
		$allStatus = acymailing_loadObjectList('SELECT order_status_id as code, name FROM #__mijoshop_order_status WHERE language_id = '.$this->lang_id.' ORDER BY name ASC');
		$firstStatus = new stdClass();
		$firstStatus->name = acymailing_translation('ALL_STATUS');
		$firstStatus->code = '0';
		array_unshift($allStatus, $firstStatus);

		if(!empty($allProducts)){
			$allCats = acymailing_loadObjectList('SELECT DISTINCT category_id as value, name as text FROM #__mijoshop_category_description WHERE language_id = '.$this->lang_id);
			$selectOne = new stdClass();
			$selectOne->value = 0;
			$selectOne->text = acymailing_translation('ACY_ANY_CATEGORY');
			array_unshift($allCats, $selectOne);

			$return .= '<div id="filter__num__mijorder">'.acymailing_select($buy, "filter[__num__][mijorder][type]", 'class="inputbox" onchange="countresults(__num__)" size="1" style="max-width:150px"', 'value', 'text', 1).' ';
			$return .= acymailing_select($allProducts, "filter[__num__][mijorder][product]", 'class="inputbox" style="max-width:200px" onchange="countresults(__num__)" size="1"', 'value', 'text');
			$return .= acymailing_select($allCats, "filter[__num__][mijorder][cat]", 'class="inputbox" style="max-width:200px" onchange="countresults(__num__)" size="1"', 'value', 'text');
			$return .= ' '.acymailing_select($allStatus, "filter[__num__][mijorder][status]", 'class="inputbox" onchange="countresults(__num__)" size="1"', 'code', 'name');
			$return .= '<br /><input type="text" name="filter[__num__][mijorder][creationdateinf]" onchange="countresults(__num__)" style="width:100px" /> < '.acymailing_translation('CREATED_DATE').' < <input type="text" name="filter[__num__][mijorder][creationdatesup]" onchange="countresults(__num__)" style="width:100px" />';
			$return .= '<br /><input type="text" name="filter[__num__][mijorder][modifdateinf]" onchange="countresults(__num__)" style="width:100px" /> < '.acymailing_translation('MODIFIED_DATE').' < <input type="text" name="filter[__num__][mijorder][modifdatesup]" onchange="countresults(__num__)" style="width:100px" />';
			$return .= '</div>';
			$type['mijorder'] = 'MijoShop : '.acymailing_translation('ACY_PRODUCTS');
		}

		$allGroups = acymailing_loadObjectList('SELECT customer_group_id AS id, name FROM #__mijoshop_customer_group_description WHERE language_id = '.$this->lang_id);

		if(count($allGroups) > 1){
			$groups = array();
			$groups[] = acymailing_selectOption('0', '- - -');
			foreach($allGroups as $oneGroup){
				$groups[] = acymailing_selectOption($oneGroup->id, $oneGroup->name);
			}
			$operators = acymailing_get('type.operatorsin');
			$operators->js = 'onchange="countresults(__num__)"';
			$return .= '<div id="filter__num__mijogroups">'.$operators->display("filter[__num__][mijogroups][type]").' ';
			$return .= acymailing_select($groups, "filter[__num__][mijogroups][group]", 'class="inputbox" size="1" onchange="countresults(__num__)"', 'value', 'text');
			$return .= '</div>';
			$type['mijogroups'] = 'MijoShop : '.trim(acymailing_translation('COM_MIJOSHOP_MAIL_CUSTOMER_TEXT_CUSTOMER_GROUP'), ':');
		}

		return $return;
	}

	function onAcyProcessFilterCount_mijorder(&$query, $filter, $num){
		$this->onAcyProcessFilter_mijorder($query, $filter, $num);
		return acymailing_translation_sprintf('SELECTED_USERS', $query->count());
	}

	function onAcyProcessFilter_mijorder(&$query, $filter, $num){
		//Prepare dates
		$datesVar = array('creationdatesup', 'creationdateinf', 'modifdateinf', 'modifdatesup');
		foreach($datesVar as $oneDate){
			if(empty($filter[$oneDate])) continue;
			$filter[$oneDate] = acymailing_replaceDate($filter[$oneDate]);
			if(!is_numeric($filter[$oneDate])) $filter[$oneDate] = strtotime($filter[$oneDate]);
			if(is_numeric($filter[$oneDate])) $filter[$oneDate] = strftime('%Y-%m-%d %H:%M:%S', $filter[$oneDate]);
		}

		$where = array();
		if(!empty($filter['status'])) $where[] = $num.'mijorder.order_status_id = '.intval($filter['status']);
		if(!empty($filter['creationdateinf'])) $where[] = $num.'mijorder.date_added > '.acymailing_escapeDB($filter['creationdateinf']);
		if(!empty($filter['creationdatesup'])) $where[] = $num.'mijorder.date_added < '.acymailing_escapeDB($filter['creationdatesup']);
		if(!empty($filter['modifdateinf'])) $where[] = $num.'mijorder.date_modified > '.acymailing_escapeDB($filter['modifdateinf']);
		if(!empty($filter['modifdatesup'])) $where[] = $num.'mijorder.date_modified < '.acymailing_escapeDB($filter['modifdatesup']);

		if(!empty($where)){
			$query->leftjoin[$num.'mijorder'] = '#__mijoshop_order AS '.$num.'mijorder ON (sub.email = '.$num.'mijorder.email AND '.implode(' AND ', $where).' )';
		}else{
			$query->leftjoin[$num.'mijorder'] = '#__mijoshop_order AS '.$num.'mijorder ON sub.email = '.$num.'mijorder.email';
		}

		//Did we select a product ?
		if(!empty($filter['product'])){
			$query->leftjoin[$num.'mijoprod'] = '#__mijoshop_order_product AS '.$num.'mijoprod ON ('.$num.'mijoprod.order_id = '.$num.'mijorder.order_id AND '.$num.'mijoprod.product_id = '.intval($filter['product']).')';
		}elseif(!empty($filter['cat'])){ //Did we select a category ?
			$query->leftjoin[$num.'mijoprod'] = '#__mijoshop_order_product AS '.$num.'mijoprod ON '.$num.'mijoprod.order_id = '.$num.'mijorder.order_id';
			$query->leftjoin[$num.'mijocat'] = '#__mijoshop_product_to_category AS '.$num.'mijocat ON ('.$num.'mijocat.product_id = '.$num.'mijoprod.product_id AND '.$num.'mijocat.category_id = '.intval($filter['cat']).')';
			if(empty($filter['type'])){
				$query->where[] = $num.'mijocat.product_id IS NULL';
			}else{
				$query->where[] = $num.'mijocat.product_id IS NOT NULL';
			}
		}else{
			$query->leftjoin[$num.'mijoprod'] = '#__mijoshop_order_product AS '.$num.'mijoprod ON '.$num.'mijoprod.order_id = '.$num.'mijorder.order_id';
		}

		if(!(empty($filter['product']) && !empty($filter['cat']))){
			if(empty($filter['type'])){
				$query->where[] = $num.'mijoprod.order_id IS NULL';
			}else $query->where[] = $num.'mijoprod.order_id IS NOT NULL';
		}
	}

	function onAcyProcessFilterCount_mijogroups(&$query, $filter, $num){
		$this->onAcyProcessFilter_mijogroups($query, $filter, $num);
		return acymailing_translation_sprintf('SELECTED_USERS', $query->count());
	}

	function onAcyProcessFilter_mijogroups(&$query, $filter, $num){
		$query->leftjoin['mijocustomergroup_'.$num] = "#__mijoshop_customer as mijocustomergroup_$num ON sub.email = mijocustomergroup_$num.email AND mijocustomergroup_$num.customer_group_id = ".intval($filter['group']);
		$query->where[] = "mijocustomergroup_$num.customer_group_id ".(($filter['type'] == 'IN' || empty($filter['group'])) ? '> 0' : "IS NULL");
	}
}//endclass
?>